@@ -55,7 +55,7 @@ use vars qw( %locale_aliases );
 		   'es_ES.ISO8859-1'		=> 'es_ES.ISO8859-1',
 
 		   'es_ES@euro'			=> 'es_ES.ISO8859-15',
-		   'es_ES.ISO8859-15	'	=> 'es_ES.ISO8859-15',
+		   'es_ES.ISO8859-15'           => 'es_ES.ISO8859-15',
 		   'es_ES.ISO8859-15@euro'	=> 'es_ES.ISO8859-15',
 
 		   'eu'				=> 'eu_ES.ISO8859-1',
@@ -63,14 +63,14 @@ use vars qw( %locale_aliases );
 		   'eu_ES.ISO8859-1'		=> 'eu_ES.ISO8859-1',
 
 		   'eu_ES@euro'			=> 'eu_ES.ISO8859-15',
-		   'eu_ES.ISO8859-15	'	=> 'eu_ES.ISO8859-15',
+		   'eu_ES.ISO8859-15'		=> 'eu_ES.ISO8859-15',
 		   'eu_ES.ISO8859-15@euro'	=> 'eu_ES.ISO8859-15',
 
 		   'eu_FR'			=> 'eu_FR.ISO8859-1',
 		   'eu_FR.ISO8859-1'		=> 'eu_FR.ISO8859-1',
 
 		   'eu_FR@euro'			=> 'eu_FR.ISO8859-15',
-		   'eu_FR.ISO8859-15	'	=> 'eu_FR.ISO8859-15',
+		   'eu_FR.ISO8859-15'		=> 'eu_FR.ISO8859-15',
 		   'eu_FR.ISO8859-15@euro'	=> 'eu_FR.ISO8859-15',
 
 		   'fi'				=> 'fi_FI.ISO8859-1',
@@ -148,6 +148,7 @@ use vars qw( %locale_aliases );
 		   'ru'				=> 'ru_RU.KOI8-R',
 		   'ru_RU'			=> 'ru_RU.KOI8-R',
 		   'ru_RU.KOI8-R'		=> 'ru_RU.KOI8-R',
+		   'ru_RU.UTF-8'		=> 'ru_RU.UTF-8',
 
 		   'sk'				=> 'sk_SK.ISO8859-2',
 		   'sk_SK'			=> 'sk_SK.ISO8859-2',
@@ -157,6 +158,10 @@ use vars qw( %locale_aliases );
 		   'sl_SI'                      => 'sl_SI.ISO8859-2',
 		   'sl_SI.ISO8859-2'            => 'sl_SI.ISO8859-2',
 
+		   'sv'                         => 'sv_SE.ISO8859-1',
+		   'sv_SE'                      => 'sv_SE.ISO8859-1',
+		   'sv_SE.ISO8859-1'            => 'sv_SE.ISO8859-1',
+
 		   'tr'				=> 'tr_TR.ISO8859-9',
 		   'tr_TR'			=> 'tr_TR.ISO8859-9',
 		   'tr_TR.ISO8859-9'		=> 'tr_TR.ISO8859-9',
@@ -164,6 +169,10 @@ use vars qw( %locale_aliases );
 		   'uk'				=> 'uk_UA.UTF-8',
 		   'uk_UA'			=> 'uk_UA.UTF-8',
 		   'uk_UA.UTF-8'		=> 'uk_UA.UTF-8',
+
+		   'vi'				=> 'vi_VN.UTF-8',
+		   'vi_VN'			=> 'vi_VN.UTF-8',
+		   'vi_VN.UTF-8'		=> 'vi_VN.UTF-8',
 		   
 		   'zh_CN'			=> 'zh_CN.GB2312',
 		   'zh_CN.GB2312'		=> 'zh_CN.GB2312',
